
- [ ] synchronized webcam recording  (near term goal..next month)
  - while the scale of webcam based workflows is limited by the I/O bottlenecks of a single computer, it can provide a simplified way to record motion capture in a smaller capture volume where high fps recording is not imperitive

- [ ] MMPose tracker integration  (mid term goal....next 6 months)

- [ ] DeepLabCut integration (mid term goal...next 6 months)

- [ ] synchronized single board computer camera platform (longer term goal.... > 6 months)
  - using Raspberry Pi or similar with MIPI style camera, record high resolution/high frame rate synchronized frames